/*
 * Copyright 2004, U.S. Robotics Corporation
 * All Rights Reserved.
 * 
 * THIS SOFTWARE IS OFFERED "AS IS", AND U.S. Robotics GRANTS NO WARRANTIES OF
 * ANY KIND, EXPRESS OR IMPLIED, BY STATUTE, COMMUNICATION OR OTHERWISE. U.S.
 * Robotics SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A SPECIFIC PURPOSE OR NONINFRINGEMENT CONCERNING THIS SOFTWARE.
 *
 * $Id: pptp.c,v 1.16 2007/04/18 20:58:08 dtutuianu Exp $
 */
#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <syslog.h>
#include <ctype.h>
#include <string.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <net/if.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <net/if_arp.h>
#include <signal.h>

typedef u_int64_t u64;
typedef u_int32_t u32;
typedef u_int16_t u16;
typedef u_int8_t u8;
#include <linux/sockios.h>
#include <linux/ethtool.h>

#include <bcmnvram.h>
#include <netconf.h>
#include <shutils.h>
#include <wlutils.h>
#include <nvparse.h>
#include <rc.h>
#include <bcmutils.h>
#include <etioctl.h>
#include <bcmparams.h>


#ifdef __CONFIG_NAT__

static int
append_dns(char *ip)
{
	FILE *fp, *fp2;
	char tmp[128];

	/* Open resolv.conf to read */
	if (!(fp = fopen("/tmp/resolv.conf", "r+"))) {
		perror("/tmp/resolv.conf");
		return errno;
	}
	/* Open resolv.pptp to write */
	if (!(fp2 = fopen("/tmp/resolv.pptp.sav", "w"))) {
		perror("/tmp/resolv.pptp.sav");
		return errno;
	}
	while (fgets(tmp, sizeof(tmp), fp)) {
		fprintf(fp2, tmp);
	}
	fclose(fp2);
	fclose(fp);

	/* Now append dns server*/
	if (!(fp = fopen("/tmp/ppp/resolv.conf", "r+"))) {
		perror("/tmp/ppp/resolv.conf");
		return errno;
	}
	//if (!(fp2 = fopen("/tmp/resolv.conf", "a+"))) {
	if (!(fp2 = fopen("/tmp/resolv.conf", "w"))) {	
		perror("/tmp/resolv.conf");
		return errno;
	}
	while (fgets(tmp, sizeof(tmp), fp)) {
		fprintf(fp2, tmp);
	}

	fclose(fp2);
	fclose(fp);
	
	/* notify dnsmasq */
	snprintf(tmp, sizeof(tmp), "-%d", SIGHUP);
	eval("killall", tmp, "dnsmasq");
	
	return 0;	
}

static int
restore_dns(char *wan_ifname)
{
	char tmp[100];

	/* Use updated file as resolv.conf */
	unlink("/tmp/resolv.conf");
	unlink("/tmp/ppp/resolv.conf");
	rename("/tmp/resolv.pptp.sav", "/tmp/resolv.conf");

	/* notify dnsmasq */
	snprintf(tmp, sizeof(tmp), "-%d", SIGHUP);
	eval("killall", tmp, "dnsmasq");
	
	return 0;
}

/* KEO - call by RC's main loop routine to start pptp connection */
static int is_activated(char *what, int which)
{
    char word[256], *next;

    foreach(word, nvram_safe_get(what), next) {
        if (which-- == 0) {
		if (!strcmp(word,"1")) return 1;
	}
    }
    return 0;
}

void
start_pptp(void)
{
    FILE *fp;

    if (nvram_match("router_disable", "1"))
	return;

#ifdef __CONFIG_SES__
    /* do not bringup wan if in ses bridge disable mode */
    if (nvram_match("ses_bridge_disable", "1"))
	return;
#endif

    // do we want to launch pptp ?
    if (nvram_invmatch("wan_pptp_activated", "1"))
	return;
    //be sure that pptp settings are default
    	nvram_set("wan_pptp_ifname", "");
	nvram_set("wan_pptp_ipaddr", "0.0.0.0");
	nvram_set("wan_pptp_netmask", "0.0.0.0");
	nvram_set("wan_pptp_gateway", "0.0.0.0");
	nvram_set("wan_pptp_dns", "0.0.0.0 0.0.0.0 0.0.0.0");
		
    // create pptp's ppp common options 
    if (( fp = fopen( "/tmp/ppp/options.pptp", "w") ) != NULL ) {
	fprintf( fp, "lock noauth nobsdcomp nodeflate\n");
    	fclose( fp );
    } else {
        perror("/tmp/ppp/options.pptp");
        return;
	}
	
		
    // Check if we need to create pap secrets 
    if (is_activated("wan_pptp_auth", 0))
    {
        if (( fp = fopen( "/tmp/ppp/pap-secrets", "w") ) != NULL ) {
		
	    fprintf( fp, "%s PPTP0 %s *\n",
    		    nvram_get("wan_pptp_username"), 
		    nvram_get("wan_pptp_passwd"));
    	    fclose( fp );
	} else {
    	    perror("/tmp/ppp/pap-secrets");
	    return;
	}
    }
    else
    {
        if (( fp = fopen( "/tmp/ppp/chap-secrets", "w") ) != NULL ) {
		
	    fprintf( fp, "%s PPTP0 %s *\n",
	        nvram_get("wan_pptp_username"), nvram_get("wan_pptp_passwd"));
    	    fclose( fp );
	} else {
	    perror("/tmp/ppp/chap-secrets");
	    return;
	}
    }
    // create tunnel peer directory
    mkdir("/tmp/ppp/peers", 0777);

    // create tunnel peer parameters
    if (( fp = fopen( "/tmp/ppp/peers/PPTP0", "w") ) != NULL ) {
	//fprintf( fp, "# name of tunnel, used to select lines in secrets files\n");
	fprintf( fp, "remotename PPTP0\n");
	//fprintf( fp, "# name of tunnel, used to name /var/run pid file\n");
	fprintf( fp, "linkname PPTP0\n");
	//fprintf( fp, "# name of tunnel, passed to ip-up scripts argv[6]\n");
	fprintf( fp, "ipparam PPTP0\n");
	//fprintf( fp, "# data stream for pppd to use\n");
	fprintf( fp, "pty \"pptp %s --nolaunchpppd\"\n",nvram_get("wan_pptp_server"));
	//fprintf( fp, "# domain and username, used to select lines in secrets files\n");
	fprintf( fp, "name %s\n",nvram_get("wan_pptp_username"));
	if (!is_activated("wan_pptp_auth", 0))
	    fprintf( fp, "refuse-pap\n");
	if (!is_activated("wan_pptp_auth", 1))
	    fprintf( fp, "refuse-chap\n");
	if (!is_activated("wan_pptp_auth", 2))
	     fprintf( fp, "refuse-mschap\n");
	if (!is_activated("wan_pptp_auth", 3))
	    fprintf( fp, "refuse-mschap-v2\n");
	fprintf( fp, "refuse-eap\n");
	fprintf( fp, "noccp\n");
	/*if (nvram_invmatch("wan_pptp_mppe", "0 0"))
	{
	    if (is_activated("wan_pptp_mppe", 0))
		fprintf( fp, "require-mppe-40\n");
		//fprintf( fp, "+mppe-40\n");
	    //else
		//fprintf( fp, "nomppe-40\n");
		
	    if (is_activated("wan_pptp_mppe", 1))
		fprintf( fp, "require-mppe-128\n");
		//fprintf( fp, "+mppe-128\n");
	    //else
		//fprintf( fp, "nomppe-128\n");
	}
	if (nvram_match("wan_pptp_mppe_mode", "1"))
	    fprintf( fp, "mppe-stateful\n"); */
        //fprintf( fp, "# do not require the server to authenticate to our client\n");
        fprintf( fp, "noauth\n");
	fprintf( fp, "file /tmp/ppp/options.pptp\n");
	fprintf( fp, "usepeerdns\n");
	/* KEO 21/02/2005, this allows pptp to reconnect after restart or loosing  */
	fprintf( fp, "maxfail 0\n");	//try to reconnect for ever
	fprintf( fp, "persist\n");
	fprintf( fp, "holdoff 10\n");
	
	fprintf( fp, "lcp-echo-failure 3\n");
	fprintf( fp, "lcp-echo-interval 10\n");
	fprintf( fp, "mtu %s\n",nvram_get("wan_pptp_mtu"));
	fprintf( fp, "mru %s\n",nvram_get("wan_pptp_mru"));
	/*if (nvram_match("wan_pptp_demand", "1"))
	{	
		fprintf( fp, "demand");
		fprintf( fp, "holdoff 10\n");
		fprintf( fp, "idle %s\n",nvram_get("wan_pptp_idletime"));
	}*/
	fclose( fp );
    } else 	{
	perror("/tmp/ppp/peers/PPTP0");
	return;
    }
 
	    /* Allow new connections from the WAN side for our */
	if (nvram_invmatch("fw_disable", "1")) {
    		netconf_filter_t filter;
		int log_level, log_accept;
	
		// Optionally log connections 
		log_level = atoi(nvram_safe_get("log_level"));
		log_accept = (log_level & 2) ? NETCONF_LOG_ACCEPT : NETCONF_ACCEPT;
	    
		memset(&filter, 0, sizeof(filter));
		filter.match.state = NETCONF_NEW;
		strcpy(filter.match.in.name, nvram_get("wan_ifname"));
		filter.target = log_accept;
		inet_aton(nvram_get("wan_pptp_server"), &filter.match.src.ipaddr);
		inet_aton(nvram_get("wan0_ipaddr"), &filter.match.dst.ipaddr);
		filter.match.dst.netmask.s_addr = htonl(0xffffffff);
		filter.match.src.netmask.s_addr = htonl(0xffffffff);
		filter.dir = NETCONF_IN;
		netconf_add_filter(&filter);

		filter.dir = NETCONF_FORWARD;
		netconf_add_filter(&filter);
	}
    
	char *pptp_argv[] = {   "pppd", 
				"call",
				"PPTP0",
				//"dump",
				NULL};
	int pid;
	/* Start ppp daemon */
	cprintf("start_pptp\n");
#ifdef ROUTER	
	set_wan_led_mode(0); 	/* turn off LED */
#else
	wan_led_off(); 	/* turn off LED */
#endif	/* ROUTER */
	
	/* KEO load mppe module */
	//if (nvram_invmatch("wan_pptp_mppe", "0 0"))
	//	eval("insmod", "ppp_mppe");
	_eval(pptp_argv, ">/dev/console", 0, &pid);
}


void
stop_pptp(void)
{
	char tmp[] = "XXXX";
	/* We are here does not mean that all pptp processes are down	*/
	snprintf(tmp, sizeof(tmp), "-%d", SIGHUP);
	//eval("killall", tmp, "pptp");
	eval("ifconfig", nvram_get("wan_pptp_ifname"), "down");
	cprintf("ifconfig done!\n");
	eval("killall", tmp, "pppd");
	cprintf("pppd killed; unlink...");
	sleep(2);
	/* Remove dynamically created links */
	unlink("/tmp/ppp/pap-secrets");
	unlink("/tmp/ppp/chap-secrets");
	unlink("/tmp/ppp/options.pptp");
	unlink("/tmp/ppp/peers/PPTP0");
	rmdir("/tmp/ppp/peers");
	cprintf("done\n");
}


void pptp_up(char *wan_ifname, char *local, char *remote, char *mask, char* dns1, char* dns2)
{
	char net1[32];
	struct in_addr in_addr, in_netmask;
	char buf[256];
	
	nvram_set("wan_pptp_ifname", wan_ifname);
	//cprintf("ip-up-pptp: %s\n", wan_ifname);
	
	/* save ip information */
	if (local) {
		cprintf("IP-UP: IPLOCAL=%s\n", local);
		nvram_set("wan_pptp_ipaddr", local);
		nvram_set("wan_pptp_netmask", mask);
#ifdef ROUTER		
		set_wan_led_mode(0x3);	 /* turn on wan led */ 
#else	
		wan_led_on();	 /* turn on wan led */ 
#endif	/* ROUTER */
	}
	if (remote)
		nvram_set("wan_pptp_gateway", remote);
	
	/* save dns info */
	strcpy(buf, "");
	if (dns1) {
		sprintf(buf, "%s", dns1);
		//cprintf("dns1=%s\n", buf);
	}
	if (dns2) {
		sprintf(buf + strlen(buf), "%s%s", strlen(buf) ? " " : "", dns2);
		//cprintf("dns2=%s\n", buf);
	}
	if (strlen(buf))
	    nvram_set("wan_pptp_dns", buf);
	
	/* Install interface dependent static routes */
	inet_aton(remote, &in_addr);
	inet_aton(mask, &in_netmask);
	in_addr.s_addr &= in_netmask.s_addr;
	strcpy(net1,inet_ntoa(in_addr));
	
	cprintf("ip-up-pptp: %s / %s\n", net1, mask);

	if (nvram_match("wan_proto","pppoe"))
	    route_add(wan_ifname, 1, net1, remote, mask);
	else {
	    // Add dns servers to resolv.conf 
	    append_dns(local);

	    /* Sync time */
	    //start_ntpc();
	}
	start_firewall3(wan_ifname, local, remote, mask);
	/* Sync time */
	start_ntpc();
#ifdef ROUTERN
	start_ddnsd(wan_ifname);
#endif	/* ROUTERN */
#ifdef ROUTER_CR
	start_ddnsd(wan_ifname);
#endif	/* ROUTERG */
	//cprintf("ip-up-pptp: done\n");
}

void pptp_down(char *wan_ifname, char *local, char *remote, char *mask)
{
	char net1[32];
	//char *t, tmp[100];
	struct in_addr in_addr, in_netmask;
	
	nvram_set("wan_pptp_ifname", "");
	nvram_set("wan_pptp_ipaddr", "0.0.0.0");
	nvram_set("wan_pptp_netmask", "0.0.0.0");
	nvram_set("wan_pptp_gateway", "0.0.0.0");
	nvram_set("wan_pptp_dns", "0.0.0.0 0.0.0.0 0.0.0.0");
	nvram_commit();
#ifdef ROUTER	
	set_wan_led_mode(0); 	/* turn off WAN LED */
#else
	wan_led_off(); 	/* turn off WAN LED */
#endif	/* ROUTER */

	//cprintf("ip-down-pptp: %s\n", wan_ifname);

	/* Remove interface dependent static routes */
	inet_aton(remote, &in_addr);
	inet_aton(mask, &in_netmask);
	in_addr.s_addr &= in_netmask.s_addr;
	strcpy(net1,inet_ntoa(in_addr));

	cprintf("ip-down-pptp: %s / %s\n", net1, mask);
	
	if (nvram_match("wan_proto","pppoe"))
    	    route_del(wan_ifname, 1, net1, remote, mask);
	else {
	    // Update resolv.conf 
	    restore_dns(nvram_get("wan_ifname"));
	}

	stop_firewall3(wan_ifname, local, remote, mask);

	//cprintf("ip-down-pptp: done\n");
}

#endif	/* __CONFIG_NAT__ */
