/*
 * Copyright 2006, U.S. Robotics Corporation
 * All Rights Reserved.
 * 
 * THIS SOFTWARE IS OFFERED "AS IS", AND U.S. Robotics GRANTS NO WARRANTIES OF
 * ANY KIND, EXPRESS OR IMPLIED, BY STATUTE, COMMUNICATION OR OTHERWISE. U.S.
 * Robotics SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A SPECIFIC PURPOSE OR NONINFRINGEMENT CONCERNING THIS SOFTWARE.
 *
 * $Id$
 */
/*
 * udhcpc scripts
 *
 * Copyright 2006, Broadcom Corporation
 * All Rights Reserved.
 * 
 * THIS SOFTWARE IS OFFERED "AS IS", AND BROADCOM GRANTS NO WARRANTIES OF ANY
 * KIND, EXPRESS OR IMPLIED, BY STATUTE, COMMUNICATION OR OTHERWISE. BROADCOM
 * SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A SPECIFIC PURPOSE OR NONINFRINGEMENT CONCERNING THIS SOFTWARE.
 *
 * $Id$
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <net/route.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <errno.h>
#include <time.h>
#include <unistd.h>

#include <bcmnvram.h>
#include <netconf.h>
#include <shutils.h>
#include <rc.h>


#ifdef __CONFIG_NAT__
#ifndef AP_CR

#include <signal.h>
#include <string.h>
#define sys_restart() kill(1, SIGHUP)
#define sys_reboot() kill(1, SIGTERM)

static int
expires(char *wan_ifname, unsigned int in)
{
	time_t now;
	FILE *fp;
	char tmp[100];
	int unit;

	if ((unit = wan_ifunit(wan_ifname)) < 0)
		return -1;
	
	time(&now);
	snprintf(tmp, sizeof(tmp), "/tmp/udhcpc%d.expires", unit); 
	if (!(fp = fopen(tmp, "w"))) {
		perror(tmp);
		return errno;
	}
	fprintf(fp, "%d", (unsigned int) now + in);
	fclose(fp);
	return 0;
}	

/* 
 * deconfig: This argument is used when udhcpc starts, and when a
 * leases is lost. The script should put the interface in an up, but
 * deconfigured state.
*/
static int
deconfig(void)
{
	char *wan_ifname = safe_getenv("interface");

	ifconfig(wan_ifname, IFUP,
		 "0.0.0.0", NULL);
	expires(wan_ifname, 0);

	wan_down(wan_ifname);

	dprintf("done\n");
	return 0;
}

/*
 * bound: This argument is used when udhcpc moves from an unbound, to
 * a bound state. All of the paramaters are set in enviromental
 * variables, The script should configure the interface, and set any
 * other relavent parameters (default gateway, dns server, etc).
*/
static int
bound(int x)
{
	char *wan_ifname = safe_getenv("interface");
	char *value;
	char tmp[100], prefix[] = "wanXXXXXXXXXX_";
	int unit;
	char val[20];
	
	
	if ((unit = wan_ifunit(wan_ifname)) < 0)
		return -1;

	snprintf(prefix, sizeof(prefix), "wan%d_", unit);
	
	if ((value = getenv("ip"))) {
		sscanf(value,"%s", val);
		nvram_set(strcat_r(prefix, "ipaddr", tmp), val);
	}

#ifdef ROUTER_CR		
	if (!strcmp(nvram_safe_get("auto_bridge"),"1")){
		printf("INFO: Get wan_ipaddress--> %s\n", value);
		in_addr_t uintWANIP;

		uintWANIP= inet_network(value);
		if ((uintWANIP & 0xffffff00)>=0xc0a80000 && (uintWANIP & 0xffffff00)<=0xc0a80900) {
			printf("INFO: %s is a private IP!\n", value);
			printf("INFO: set auto bridge flag\n");

			nvram_set("auto_bridge_action", "1");
			nvram_set("lan_dhcp", "1");	
			nvram_set("router_disable_auto", "1");
			/* save router's IP addresses */
			nvram_set("oldlan_ipaddr", nvram_safe_get("lan_ipaddr"));
			nvram_set("oldlan_gateway", nvram_safe_get("lan_gateway"));
			nvram_set("oldlan_dns", nvram_safe_get("lan_dns"));
			nvram_set("oldlan_netmask", nvram_safe_get("lan_netmask"));
			nvram_set("oldwan_proto", nvram_safe_get("wan_proto"));
			
			nvram_commit();

			printf("INFO: reboot \n");
			sys_reboot();
			printf("INFO: after issuing reboot \n");
			return 0;			
		}
		else
			printf("INFO: %s is not a private IP of concern!\n", value);
	}
	else
			printf("INFO: auto bridge is not enabled\n");
#endif	/* ROUTER_CR */

	if ((value = getenv("subnet")))
		nvram_set(strcat_r(prefix, "netmask", tmp), value);
        if ((value = getenv("router")))
		nvram_set(strcat_r(prefix, "gateway", tmp), value);
	if ((value = getenv("dns")))
		nvram_set(strcat_r(prefix, "dns", tmp), value);
	if ((value = getenv("wins")))
		nvram_set(strcat_r(prefix, "wins", tmp), value);
	if ((value = getenv("hostname")))
		sethostname(value, strlen(value) + 1);
	if ((value = getenv("domain")))
		nvram_set(strcat_r(prefix, "domain", tmp), value);
	if ((value = getenv("lease"))) {
		nvram_set(strcat_r(prefix, "lease", tmp), value);
		expires(wan_ifname, atoi(value));
	}

	ifconfig(wan_ifname, IFUP,
		 nvram_safe_get(strcat_r(prefix, "ipaddr", tmp)),
		 nvram_safe_get(strcat_r(prefix, "netmask", tmp)));
	
	wan_up(wan_ifname, x);	//bound with pptp active - don't create static route, don't start pptp

	dprintf("done\n");
	return 0;
}

/*
 * renew: This argument is used when a DHCP lease is renewed. All of
 * the paramaters are set in enviromental variables. This argument is
 * used when the interface is already configured, so the IP address,
 * will not change, however, the other DHCP paramaters, such as the
 * default gateway, subnet mask, and dns server may change.
 */
static int
renew(void)
{
	bound(1);	//bound with pptp active - don't create static route, don't start pptp

	dprintf("done\n");
	return 0;
}

int
udhcpc_wan(int argc, char **argv)
{
	if (!argv[1])
		return EINVAL;
	else if (strstr(argv[1], "deconfig"))
		return deconfig();
	else if (strstr(argv[1], "bound"))
		return bound(0);	//bound with pptp
	else if (strstr(argv[1], "renew"))
		return renew();
	else
		return EINVAL;
}
#endif	/* AP_CR */
#endif	/* __CONFIG_NAT__ */

static int
expires_lan(char *lan_ifname, unsigned int in)
{
	time_t now;
	FILE *fp;
	char tmp[100];

	time(&now);
	snprintf(tmp, sizeof(tmp), "/tmp/udhcpc-%s.expires", lan_ifname); 
	if (!(fp = fopen(tmp, "w"))) {
		perror(tmp);
		return errno;
	}
	fprintf(fp, "%d", (unsigned int) now + in);
	fclose(fp);
	return 0;
}	

/* 
 * deconfig: This argument is used when udhcpc starts, and when a
 * leases is lost. The script should put the interface in an up, but
 * deconfigured state.
*/
static int
deconfig_lan(void)
{
	char *lan_ifname = safe_getenv("interface");

	printf("DECONFIG LAN\n");
	ifconfig(lan_ifname, IFUP, "0.0.0.0", NULL);
	expires_lan(lan_ifname, 0);

	lan_down(lan_ifname);

	dprintf("done\n");
	return 0;
}

static int
deconfig_lan_init(void)
{
	char *lan_ifname = safe_getenv("interface");

	printf("DECONFIG LAN INIT\n");
	ifconfig(lan_ifname, IFUP, NULL, NULL);
	expires_lan(lan_ifname, 0);
	//lan_down(lan_ifname);
	dprintf("done\n");
	return 0;
}

/*
 * bound: This argument is used when udhcpc moves from an unbound, to
 * a bound state. All of the paramaters are set in enviromental
 * variables, The script should configure the interface, and set any
 * other relavent parameters (default gateway, dns server, etc).
*/
static int
bound_lan(void)
{
	char *lan_ifname = safe_getenv("interface");
	char *value;
	char val[20];
	
	if ((value = getenv("ip"))) {
		sscanf(value,"%s", val);
		nvram_set("lan_ipaddr", val);
	}
	
#ifdef ROUTER_CR	
	if (!strcmp(nvram_safe_get("auto_bridge"),"1")){
		printf("INFO: Get wan_ipaddress--> %s\n", value);
		in_addr_t uintWANIP;

		uintWANIP= inet_network(value);
		if ((uintWANIP & 0xffffff00)>=0xc0a80000 && (uintWANIP & 0xffffff00)<=0xc0a80900) {
			printf("INFO: %s is a private IP!\n", value);

			printf("INFO: keep auto bridge flag\n");
		}
		else {
			printf("INFO: %s is not a private IP, restore router settings!\n", value);
			nvram_set("auto_bridge_action", "0");
			nvram_set("lan_dhcp", "0");	
			nvram_set("router_disable_auto", "0");
			nvram_set("lan_ipaddr", nvram_safe_get("oldlan_ipaddr"));
			nvram_set("lan_gateway", nvram_safe_get("oldlan_gateway"));
			nvram_set("lan_dns", nvram_safe_get("oldlan_dns"));
			nvram_set("lan_netmask", nvram_safe_get("oldlan_netmask"));
			nvram_commit();

			printf("INFO: reboot \n");
			sys_reboot();
			printf("INFO: after issuing reboot \n");
			return 0;			
		}
	}
	else
		printf("INFO: auto bridge is not enabled\n");
#endif	/* ROUTER_CR */	
	
	if ((value = getenv("subnet"))) {
		sscanf(value,"%s", val);
		nvram_set("lan_netmask", val);
	}
        if ((value = getenv("router"))) {
		sscanf(value,"%s", val);
		nvram_set("lan_gateway", val);
	}
	if ((value = getenv("dns"))) {
		sscanf(value,"%s", val);
		nvram_set("lan_dns", val);
	}
	if ((value = getenv("lease")))
		expires_lan(lan_ifname, atoi(value));

	ifconfig(lan_ifname, IFUP, nvram_safe_get("lan_ipaddr"),
		nvram_safe_get("lan_netmask"));

	lan_up(lan_ifname);

	dprintf("done\n");
	return 0;
}

/*
 * renew: This argument is used when a DHCP lease is renewed. All of
 * the paramaters are set in enviromental variables. This argument is
 * used when the interface is already configured, so the IP address,
 * will not change, however, the other DHCP paramaters, such as the
 * default gateway, subnet mask, and dns server may change.
 */
static int
renew_lan(void)
{
	bound_lan();

	dprintf("done\n");
	return 0;
}

/* dhcp client script entry for LAN (AP) */
int
udhcpc_lan(int argc, char **argv)
{
	if (!argv[1])
		return EINVAL;
	else if (strstr(argv[1], "deconfig_init"))
		return deconfig_lan_init();
	else if (strstr(argv[1], "deconfig"))
		return deconfig_lan();
	else if (strstr(argv[1], "bound"))
		return bound_lan();
	else if (strstr(argv[1], "renew"))
		return renew_lan();
	else
		return EINVAL;
}
