/*
 * Copyright 2006, U.S. Robotics Corporation
 * All Rights Reserved.
 * 
 * THIS SOFTWARE IS OFFERED "AS IS", AND U.S. Robotics GRANTS NO WARRANTIES OF
 * ANY KIND, EXPRESS OR IMPLIED, BY STATUTE, COMMUNICATION OR OTHERWISE. U.S.
 * Robotics SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A SPECIFIC PURPOSE OR NONINFRINGEMENT CONCERNING THIS SOFTWARE.
 *
 * $Id: wan_gpio.c,v 1.5 2007/08/23 20:06:13 dtutuianu Exp $
 */

#include <typedefs.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <signal.h>
#include <assert.h>
#include <bcmnvram.h>
//#include <bcmgpio.h>
#include <projects.h>
#include "wan_gpio.h"

static int wan_led_gpio = BCMGPIO_UNDEFINED;

int wan_gpio_led_init()
{
#ifdef ROUTERN
	wan_led_gpio = 7;
#else
	wan_led_gpio = 4;
#endif

	if (bcmgpio_connect(wan_led_gpio, BCMGPIO_DIRN_OUT) != 0) {
		printf("Error connecting GPIO %d to WAN led\n", wan_led_gpio);
		return -1;
	}

	return 0;
}

void wan_gpio_led_cleanup()
{
	if (wan_led_gpio != BCMGPIO_UNDEFINED) {
		bcmgpio_disconnect(wan_led_gpio);
		wan_led_gpio = BCMGPIO_UNDEFINED;
	}
}

void wan_led_on()
{
	unsigned long led_mask;
	
	printf("WAN LED on!\n");
	wan_gpio_led_init();
	
	if (wan_led_gpio == BCMGPIO_UNDEFINED)
		return;

	led_mask = ((unsigned long)1 << wan_led_gpio);
	bcmgpio_out(led_mask, led_mask);
	wan_gpio_led_cleanup();
}

void wan_led_off()
{
	unsigned long led_mask;
	unsigned long value;

	printf("WAN LED off!\n");
	wan_gpio_led_init();

	if (wan_led_gpio == BCMGPIO_UNDEFINED)
		return;

	led_mask = ((unsigned long)1 << wan_led_gpio);
	value = ((unsigned long) ~1 << wan_led_gpio);
	value &= led_mask;
	
	bcmgpio_out(led_mask, value);
	
	wan_gpio_led_cleanup();
}
