/*
 * Copyright 2006, U.S. Robotics Corporation
 * All Rights Reserved.
 * 
 * THIS SOFTWARE IS OFFERED "AS IS", AND U.S. Robotics GRANTS NO WARRANTIES OF
 * ANY KIND, EXPRESS OR IMPLIED, BY STATUTE, COMMUNICATION OR OTHERWISE. U.S.
 * Robotics SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A SPECIFIC PURPOSE OR NONINFRINGEMENT CONCERNING THIS SOFTWARE.
 *
 * $Id$
 */
/*
 * Router default NVRAM values
 *
 * Copyright 2006, Broadcom Corporation
 * All Rights Reserved.
 * 
 * THIS SOFTWARE IS OFFERED "AS IS", AND BROADCOM GRANTS NO WARRANTIES OF ANY
 * KIND, EXPRESS OR IMPLIED, BY STATUTE, COMMUNICATION OR OTHERWISE. BROADCOM
 * SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A SPECIFIC PURPOSE OR NONINFRINGEMENT CONCERNING THIS SOFTWARE.
 *
 */

#include <epivers.h>
#include <typedefs.h>
#include <string.h>
#include <bcmnvram.h>
#include <wlioctl.h>
#include <stdio.h>
#include <ezc.h>
#include <bcmconfig.h>
/*USR*/
#include "projects.h"

#define XSTR(s) STR(s)
#define STR(s) #s

struct nvram_tuple router_defaults[] = {
	/* OS parameters */
	{ "os_name", "", 0 },			/* OS name string */
	{ "os_version", EPI_VERSION_STR, 0 },	/* OS revision */
	{ "os_date", __DATE__, 0 },		/* OS date */

	/* Miscellaneous parameters */
	{ "log_ipaddr", "", 0 },		/* syslog recipient */
	{ "timer_interval", "3600", 0 },	/* Timer interval in seconds */
	{ "ntp_server", "192.43.244.18 81.168.107.97 128.252.19.1", 0 },		/* NTP server */
	{ "time_zone", "PST8PDT", 0 },		/* Time zone (GNU TZ format) */
#ifdef CR
	{ "upnp_enable", "1", 1 },
#else	
	{ "upnp_enable", "0", 0 },
#endif	/* CR */		
#ifdef NPHY
	{ "ezc_enable", "1", 0 },		/* Enable EZConfig updates */
	{ "ezc_version", EZC_VERSION_STR, 0 },	/* EZConfig version */
	/* SES parameters */
	{ "ses_enable", "1", 0 },		/* enable ses */
	{ "ses_event", "2", 0 },		/* initial ses event */
	{ "ses_wds_mode", "1", 0 },		/* enabled if ses cfgd */
	/* SES client parameters */
	{ "ses_cl_enable", "1", 0 },		/* enable ses */
	{ "ses_cl_event", "0", 0 },		/* initial ses event */
#endif /* NPHY */
	{ "is_default", "1", 0 },		/* is it default setting: 1:yes 0:no*/
	{ "os_server", "", 0 },			/* URL for getting upgrades */
	{ "console_loglevel", "1", 0 },		/* Kernel panics only */

	/* LAN H/W parameters */
	{ "lan_ifname", "", 0 },		/* LAN interface name */
	{ "lan_ifnames", "", 0 },		/* Enslaved LAN interfaces */
	{ "lan_hwnames", "", 0 },		/* LAN driver names (e.g. et0) */
	{ "lan_hwaddr", "", 0 },		/* LAN interface MAC address */
	/* LAN TCP/IP parameters */
	{ "lan_netmask", "255.255.255.0", 0 },	/* LAN netmask */
	{ "lan_wins", "", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "lan_domain", "", 0 },		/* LAN domain name */
	{ "lan_route", "", 0 },			/* Static routes (ipaddr:netmask:gateway:metric:ifname ...) */
	{ "ure_disable", "1", 0 },		/* sets APSTA for radio and puts wireless interfaces in correct lan */
#ifdef CLIENT	
	{ "lan_lease", "6", 0 },		/* LAN lease time in seconds */
#else
	{ "lan_lease", "3600", 0},
#endif	/* CLIENT */
	
#ifdef CLIENT
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.201", 0 },	/* LAN IP address */
	{ "lan_gateway", "192.168.1.201", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "dhcp_start", "192.168.1.202", 0 },	/* First assignable DHCP address */
	{ "dhcp_end", "192.168.1.202", 0 },	/* Last assignable DHCP address */
	{ "lan_dhcp", "0", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "wet", 0 },		/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "", 0 },			/* Service set ID (network name) */
	{ "wl_sta_retry_time", "5", 0 }, 	/* Seconds between association attempts */
	{ "wl_afterburner", "off", 0 },		/* AfterBurner */
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "frameburst", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.201", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "COMPAT_ID", "5", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif /* CLIENT */
#ifdef REPEATER
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5441", 0 },
	{ "wl_afterburner", "auto", 0 },	/* AfterBurner */
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_lazywds", "0", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "COMPAT_ID", "4", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif	/* REPEATER */
#ifdef AP
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5451", 0 },
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_afterburner", "auto", 0 },	/* AfterBurner */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },			/* x.x.x.x x.x.x.x ... */
#ifdef FASTWEB	
	{ "wl_multicast", "off", 0 },		/* USR - enable/disable multicast (on/off) */
#else
	{ "wl_multicast", "on", 0 },		/* USR - enable/disable multicast (on/off) */
#endif 	/* FASTWEB */		
	{ "COMPAT_ID", "2", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif	/* AP */
#ifdef ROUTER
	{ "router_disable", "0", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "log_level", "0", 0 },		/* Bitmask 0:off 1:denied 2:accepted */
	{ "stats_server", "", 0 },		/* URL for posting stats */
	/* Big switches */
	{ "fw_disable", "0", 0 },		/* Disable firewall (allow new connections from the WAN) */
	{ "lan_ipaddr", "192.168.2.1", 0 },
	{ "lan_gateway", "192.168.2.1", 0 },	/* LAN gateway */
	{ "lan_stp", "1", 0 },			/* LAN spanning tree protocol */
	{ "dhcp_start", "192.168.2.2", 0 },
	{ "dhcp_end", "192.168.2.31", 0},
	{ "lan_dhcp", "0", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "lan_dns", "192.168.2.1", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5461", 0 },
	{ "wl_afterburner", "auto", 0 },		/* AfterBurner */
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "COMPAT_ID", "1", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
	{ "sysdbg", "off", 0 },			/* syslog firewall enabled/disabled: on/off */
#endif	/* ROUTER */
#ifdef GAMING
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "wet", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5431", 0 },
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_afterburner", "auto", 0 },		/* AfterBurner */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_sta_retry_time", "5", 0 }, /* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "COMPAT_ID", "6", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif	/* GAMING */
#ifdef BRIDGE
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "wet", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5432", 0 },
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_afterburner", "auto", 0 },		/* AfterBurner */
	{ "wl_lazywds", "0", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_sta_retry_time", "5", 0 }, /* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "COMPAT_ID", "7", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif	/* BRIDGE */
#ifdef ROUTERN
	{ "router_disable", "0", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "log_level", "0", 0 },		/* Bitmask 0:off 1:denied 2:accepted */
	{ "stats_server", "", 0 },		/* URL for posting stats */
	/* Big switches */
	{ "fw_disable", "0", 0 },		/* Disable firewall (allow new connections from the WAN) */
	{ "lan_ipaddr", "192.168.2.1", 0 },
	{ "lan_gateway", "192.168.2.1", 0 },	/* LAN gateway */
	{ "lan_stp", "1", 0 },			/* LAN spanning tree protocol */
	{ "dhcp_start", "192.168.2.2", 0 },
	{ "dhcp_end", "192.168.2.31", 0},
	{ "lan_dhcp", "0", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "lan_dns", "192.168.2.1", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5464", 0 },
	{ "wl_afterburner", "off", 0 },	/* AfterBurner */
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "frameburst", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "COMPAT_ID", "8", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
	{ "ddns_list0", "", 0 },		/* format for dyn dns list: "hostname:username:password:service:active "(space after active, active values on/off) */
	{ "sysdbg", "off", 0 },			/* syslog firewall enabled/disabled: on/off */
	{ "static_lease", "", 0 },			/* syslog firewall enabled/disabled: on/off */
#endif	/* ROUTERN */
#ifdef ROUTER_CR
	{ "router_disable", "0", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "log_level", "0", 0 },		/* Bitmask 0:off 1:denied 2:accepted */
	{ "stats_server", "", 0 },		/* URL for posting stats */
	/* Big switches */
	{ "fw_disable", "0", 0 },		/* Disable firewall (allow new connections from the WAN) */
	{ "lan_ipaddr", "192.168.2.1", 0 },
	{ "lan_gateway", "192.168.2.1", 0 },	/* LAN gateway */
	{ "lan_stp", "1", 0 },			/* LAN spanning tree protocol */
	{ "dhcp_start", "192.168.2.2", 0 },
	{ "dhcp_end", "192.168.2.31", 0},
	{ "lan_dhcp", "0", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "lan_dns", "192.168.2.1", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5465", 0 },
	{ "wl_afterburner", "auto", 0 },	/* AfterBurner */
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "COMPAT_ID", "10", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
	{ "ddns_list0", "", 0 },		/* format for dyn dns list: "hostname:username:password:service:active "(space after active, active values on/off) */
	{ "sysdbg", "off", 0 },			/* syslog firewall enabled/disabled: on/off */
	{ "static_lease", "", 0 },		/* DHCP static lease list: mac_address ip_address */
	{ "wsc_modelname", "USRobotics Wireless MAXg Router", 0 },		
	{ "wsc_device_name", "USRobotics Wireless MAXg Router", 0 },
	{ "wsc_modelnum", "USR5465", 0 },
#endif	/* ROUTER_CR */
#ifdef ROUTERG
	{ "router_disable", "0", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "log_level", "0", 0 },		/* Bitmask 0:off 1:denied 2:accepted */
	/* Big switches */
	{ "fw_disable", "0", 0 },		/* Disable firewall (allow new connections from the WAN) */
	{ "lan_ipaddr", "192.168.2.1", 0 },
	{ "lan_gateway", "192.168.2.1", 0 },	/* LAN gateway */
	{ "lan_stp", "1", 0 },			/* LAN spanning tree protocol */
	{ "dhcp_start", "192.168.2.2", 0 },
	{ "dhcp_end", "192.168.2.31", 0},
	{ "lan_dhcp", "0", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "lan_dns", "192.168.2.1", 0 },	/* x.x.x.x x.x.x.x ... */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5466", 0 },
	{ "wl_afterburner", "off", 0 },	/* AfterBurner */
	{ "wl_frameburst", "off", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "COMPAT_ID", "12", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
#endif	/* ROUTERG */
#ifdef APN
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5454", 0 },
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_afterburner", "off", 0 },	/* AfterBurner */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "frameburst", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },	/* x.x.x.x x.x.x.x ... */
#ifdef FASTWEB	
	{ "wl_multicast", "off", 0 },		/* USR - enable/disable multicast (on/off) */
#else
	{ "wl_multicast", "on", 0 },		/* USR - enable/disable multicast (on/off) */
#endif 	/* FASTWEB */
	{ "COMPAT_ID", "9", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
	{ "extender", "0", 0 },			/* value of 1 if the AP is used as range extender */
	{ "scanvar", "ap", 0 },			/* value of 1 if the AP is used as range extender */
#endif	/* APN */
#ifdef AP_CR
	{ "router_disable", "1", 0 },		/* lan_proto=static lan_stp=0 wan_proto=disabled */
	{ "fw_disable", "0", 0 },		/* Disable firewall (allow new connections from the WAN) */
	{ "lan_ipaddr", "192.168.1.64", 0 },
	{ "lan_gateway", "192.168.1.64", 0 },	/* LAN gateway */
	{ "lan_stp", "0", 0 },			/* LAN spanning tree protocol */
	{ "lan_dhcp", "1", 0 },			/* DHCP client [static|dhcp] */
	{ "lan_proto", "dhcp", 0 },		/* DHCP server [static|dhcp] */
	{ "wl_mode", "ap", 0 },			/* AP mode (ap|sta|wds) */
	{ "wl_ssid", "USR5455", 0 },
	{ "wl_frameburst", "on", 0 },		/* BRCM Frambursting mode (off|on) */
	{ "wl_afterburner", "auto", 0 },	/* AfterBurner */
	{ "wl_lazywds", "1", 0 },		/* Enable/Disable "restriction" WDS mode (0|1) */
	{ "wl_radius_ipaddr", "", 0 },		/* RADIUS server IP address */
	{ "wl_radius_key", "", 0 },		/* RADIUS shared secret */
	{ "wl_radius_port", "1812", 0 },	/* RADIUS server UDP port */
	{ "wl_sta_retry_time", "0", 0 }, 	/* Seconds between association attempts */
	{ "wl_mrate", "0", 0 },			/* Mcast Rate (bps, 0 for auto) */
	{ "cbAcceleration", "afterburner", 0 },  /* USR-acceleration (none|frameburst|afterburner) */
	{ "lan_dns", "192.168.1.64", 0 },	/* x.x.x.x x.x.x.x ... */
#ifdef FASTWEB	
	{ "wl_multicast", "off", 0 },		/* USR - enable/disable multicast (on/off) */
#else
	{ "wl_multicast", "on", 0 },		/* USR - enable/disable multicast (on/off) */
#endif 	/* FASTWEB */	
	{ "COMPAT_ID", "11", 0 },		/* compatibility ID */
	{ "HARDWARE_REV", "1", 0 },		/* syslog recipient */
	{ "wsc_modelname", "USRobotics Wireless MAXg Access Point", 0 },		
	{ "wsc_device_name", "USRobotics MAXg Access Point", 0 },
	{ "wsc_modelnum", "USR5455", 0 },
#endif	/* AP_CR */
#ifdef __CONFIG_NAT__
	/* WAN H/W parameters */
	{ "wan_ifname", "", 0 },		/* WAN interface name */
	{ "wan_ifnames", "", 0 },		/* WAN interface names */
	{ "wan_hwname", "", 0 },		/* WAN driver name (e.g. et1) */
	{ "wan_hwaddr", "", 0 },		/* WAN interface MAC address */
	/* WAN TCP/IP parameters */
#ifdef AP_CR
	{ "wan_proto", "disabled", 0 },		/* [static|dhcp|pppoe|disabled] */
#else
	{ "wan_proto", "dhcp", 0 },		/* [static|dhcp|pppoe|disabled] */
#endif	/* AP_CR */
#ifndef AP_CR
	/* WAN TCP/IP parameters */
	{ "wan_ipaddr", "0.0.0.0", 0 },		/* WAN IP address */
	{ "wan_netmask", "0.0.0.0", 0 },	/* WAN netmask */
	{ "wan_gateway", "0.0.0.0", 0 },	/* WAN gateway */
	{ "wan_dns", "", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "wan_wins", "", 0 },			/* x.x.x.x x.x.x.x ... */
	{ "wan_hostname", "", 0 },		/* WAN hostname */
	{ "wan_domain", "", 0 },		/* WAN domain name */
	{ "wan_lease", "86400", 0 },		/* WAN lease time in seconds */

	/* PPPoE parameters */
	{ "wan_pppoe_ifname", "", 0 },		/* PPPoE enslaved interface */
	{ "wan_pppoe_username", "", 0 },	/* PPP username */
	{ "wan_pppoe_passwd", "", 0 },		/* PPP password */
	{ "wan_pppoe_idletime", "60", 0 },	/* Dial on demand max idle time (seconds) */
	{ "wan_pppoe_keepalive", "1", 0 },	/* Restore link automatically */
	{ "wan_pppoe_demand", "0", 0 },		/* Dial on demand */
	{ "wan_pppoe_mru", "1492", 0 },		/* Negotiate MRU to this value */
	{ "wan_pppoe_mtu", "1492", 0 },		/* Negotiate MTU to the smaller of this value or the peer MRU */
	{ "wan_pppoe_service", "", 0 },		/* PPPoE service name */
	{ "wan_pppoe_ac", "", 0 },		/* PPPoE access concentrator name */
	{ "wan_pppoe_ipaddr", "", 0 },		/* PPPoE static IP */
	{ "wan_pppoe_static", "0", 0 },		/* PPPoE static IP enabled/disabled 1/0 */
	/* PPTP parameters */
	{ "wan_pptp_activated", "0", 0 },	/* PPTP activation status */
	{ "wan_pptp_ifname", "", 0 },		/* PPTP enslaved interface */
	{ "wan_pptp_server", "", 0 },		/* PPTP server */
	{ "wan_pptp_username", "", 0 },		/* PPP username */
	{ "wan_pptp_passwd", "", 0 },		/* PPP password */
	{ "wan_pptp_auth", "0 1 1 1", 0 },	/* authentication required: 1 = PAP; 2 = CHAP; 4 = MSCHAP; 8 = MSCHAP-v2 */
	{ "wan_pptp_ipaddr", "0.0.0.0", 0 },	/* PPTP ipaddress*/
	{ "wan_pptp_netmask", "0.0.0.0", 0 },	/* PPTP netmask */
	{ "wan_pptp_gateway", "0.0.0.0", 0 },	/* PPTP gateway */
	{ "wan_pptp_dns", "", 0 },		/* PPTP gateway */
	{ "wan_pptp_mru", "1460", 0 },		/* Negotiate MRU to this value */
	{ "wan_pptp_mtu", "1460", 0 },		/* Negotiate MTU to the smaller of this value or the peer MRU */
	//{ "wan_pptp_idletime", "60", 0 },	/* Dial on demand max idle time (seconds) */
	//{ "wan_pptp_demand", "0", 0 },	/* Dial on demand */
	//{ "wan_pptp_mppe", "0 0", 0 },	/* MPPE Encryption required: 0 = none; 1 = 40 bits; 2 = 128 bits can be combined */
	//{ "wan_pptp_mppe_mode", "0", 0 },	/* MPPE mode required: 0 = stateless; 1 = statefull */
	//{ "wan_pptp_inbound", "1", 0 },
	//{ "wan_pptp_keepalive", "1", 0 },	/* Restore link automatically */
#endif	/* AP_CR */	
	/* Misc WAN parameters */
	{ "wan_desc", "", 0 },			/* WAN connection description */
	{ "wan_route", "", 0 },			/* Static routes (ipaddr:netmask:gateway:metric:ifname ...) */
	{ "wan_primary", "0", 0 },		/* Primary wan connection */

	{ "wan_unit", "0", 0 },			/* Last configured connection */

	/* Filters */
	{ "filter_maclist", "", 0 },		/* xx:xx:xx:xx:xx:xx ... */
	{ "filter_macmode", "deny", 0 },	/* "allow" only, "deny" only, or "disabled" (allow all) */
#ifndef AP_CR
#ifdef ROUTER
	{ "filter_client0", "", 0 },		/* [lan_ipaddr0-lan_ipaddr1|*]:lan_port0-lan_port1,proto,enable,day_start-day_end,sec_start-sec_end,desc */
	{ "filter_client1", "", 0 },		/* [lan_ipaddr0-lan_ipaddr1|*]:lan_port0-lan_port1,proto,enable,day_start-day_end,sec_start-sec_end,desc */
	{ "forward_port0", "", 0 },	/* wan_port0-wan_port1>lan_ipaddr:lan_port0-lan_port1[:,]proto[:,]enable[:,]desc */
	{ "autofw_port0", "", 0 },	/* out_proto:out_port,in_proto:in_port0-in_port1>to_port0-to_port1,enable,desc */
#else
	{ "filter_client0", "192.168.2.100-192.168.2.110:1-65535,tcp,1-5,79201-61200,off", 0 },		/* [lan_ipaddr0-lan_ipaddr1|*]:lan_port0-lan_port1,proto,enable,day_start-day_end,sec_start-sec_end,desc */
	{ "filter_client1", "192.168.2.100-192.168.2.110:1-65535,tcp,6-0,2-28800,off", 0 },		/* [lan_ipaddr0-lan_ipaddr1|*]:lan_port0-lan_port1,proto,enable,day_start-day_end,sec_start-sec_end,desc */
	{ "forward_port0", "80-80>192.168.2.120:80-80,tcp,off", 0 },		/* wan_port0-wan_port1>lan_ipaddr:lan_port0-lan_port1[:,]proto[:,]enable[:,]desc */
	{ "autofw_port0", "tcp:1-65535,tcp:10070-10080>10070-10080,off", 0 },	/* out_proto:out_port,in_proto:in_port0-in_port1>to_port0-to_port1,enable,desc */
	{ "autofw_port1", "udp:1-65535,udp:10070-10070>10070-10070,off", 0 },	/* out_proto:out_port,in_proto:in_port0-in_port1>to_port0-to_port1,enable,desc */
#endif	/* ROUTER */
	/* Port forwards */
	{ "dmz_ipaddr", "", 0 },		/* x.x.x.x (equivalent to 0-60999>dmz_ipaddr:0-60999) */
	/* DHCP server parameters */
	{ "dhcp_domain", "wan", 0 },		/* Use WAN domain name first if available (wan|lan) */
	{ "dhcp_wins", "wan", 0 },		/* Use WAN WINS first if available (wan|lan) */
	{ "dhcp_ipaddr", "", 0 },		/* dhcp client list */
#ifndef ROUTERG	
	{ "ipp_port", "1631", 0 },		/* print server port */
	{ "wan_ipp", "0", 0 },			/* remote printing: 0 = disabled, 1 = enabled */
#endif	/* ROUTERG */
#endif	/* AP_CR */
#endif	/* __CONFIG_NAT__ */
	/* Web server parameters */
#ifdef CLIENT
	{ "http_username", "admin", 0 },	/* Username */
	{ "http_passwd", "admin", 0 },		/* Password */
#else
	{ "http_username", "", 0 },		/* Username */
	{ "http_passwd", "", 0 },		/* Password */
#endif	/* CLIENT */
	{ "http_wanport", "", 0 },		/* WAN port to listen on */
	{ "http_lanport", "80", 0 },		/* LAN port to listen on */

	/* Wireless parameters */
	{ "wl_ifname", "", 0 },			/* Interface name */
	{ "wl_hwaddr", "", 0 },			/* MAC address */
	{ "wl_phytype", "g", 0 },		/* Current wireless band ("a" (5 GHz), "b" (2.4 GHz), or "g" (2.4 GHz)) */
	{ "wl_corerev", "", 0 },		/* Current core revision */
	{ "wl_phytypes", "", 0 },		/* List of supported wireless bands (e.g. "ga") */
	{ "wl_radioids", "", 0 },		/* List of radio IDs */
	//{ "wl_country", "", 0 },		/* Country (default obtained from driver) */
	//{ "wl_country_code", "", 0 },		/* Country (default obtained from driver) */
	{ "wl_radio", "1", 0 },			/* Enable (1) or disable (0) radio */
	{ "wl_closed", "0", 0 },		/* Closed (hidden) network */
        { "wl_ap_isolate", "0", 0 },            /* AP isolate mode */
	{ "wl_wds", "", 0 },			/* xx:xx:xx:xx:xx:xx ... */
	{ "wl_wds_timeout", "1", 0 },		/* WDS link detection interval */
	{ "wl_wep", "disabled", 0 },		/* WEP data encryption (enabled|disabled) */
	{ "wl_auth", "0", 0 },			/* Shared key authentication optional (0) or required (1) */
	{ "wl_key", "1", 0 },			/* Current WEP key */
	{ "wl_key1", "", 0 },			/* 5/13 char ASCII or 10/26 char hex */
	{ "wl_key2", "", 0 },			/* 5/13 char ASCII or 10/26 char hex */
	{ "wl_key3", "", 0 },			/* 5/13 char ASCII or 10/26 char hex */
	{ "wl_key4", "", 0 },			/* 5/13 char ASCII or 10/26 char hex */
	{ "wl_maclist", "", 0 },		/* xx:xx:xx:xx:xx:xx ... */
	{ "wl_macmode", "disabled", 0 },	/* "allow" only, "deny" only, or "disabled" (allow all) */
#ifdef NPHY	
	{ "wl_channel", "0", 0 },		/* Channel number - Automatic*/
#else
	{ "wl_channel", "11", 0 },		/* Channel number */
#endif	/* NPHY */
	{ "wl_reg_mode", "off", 0 },		/* Regulatory: 802.11H(h)/802.11D(d)/off(off) */
	{ "wl_dfs_preism", "60", 0 },		/* 802.11H pre network CAC time */
	{ "wl_dfs_postism", "60", 0 },		/* 802.11H In Service Monitoring CAC time */
	{ "wl_rate", "0", 0 },			/* Rate (bps, 0 for auto) */
	{ "wl_rateset", "default", 0 },		/* "default" or "all" or "12" */
	{ "wl_frag", "2346", 0 },		/* Fragmentation threshold */
	{ "wl_rts", "2347", 0 },		/* RTS threshold */
	{ "wl_dtim", "1", 0 },			/* DTIM period */
	{ "wl_bcn", "100", 0 },			/* Beacon interval */
	{ "wl_plcphdr", "long", 0 },		/* 802.11b PLCP preamble type */
	{ "wl_gmode", XSTR(GMODE_AUTO), 0 },	/* 54g mode */
	{ "wl_gmode_protection", "auto", 0 },	/* 802.11g RTS/CTS protection (off|auto) */
#ifdef ROUTERG	
	{ "wl_wme", "on", 0 },			/* WME mode (off|on) */
#else
	{ "wl_wme", "off", 0 },			/* WME mode (off|on) */
#endif /* ROUTERG */
	{ "wl_antdiv", "-1", 0 },		/* Antenna Diversity (-1|0|1|3) */
	{ "wl_infra", "1", 0 },			/* Network Type (BSS/IBSS) */
#ifdef NPHY
	{ "wl_nmode", "-1", 0 },		/* 802.11n mode (-1 (auto)| 0 (off) */
	{ "wl_nbw", "20", 0},			/* N-BW */
	{ "wl_nctrlsb", "lower", 0},		/* N-CTRL SB */
	{ "wl_nband", "2", 0},			/* N-BAND */
	{ "wl_nmcsidx", "-1", 0},		/* MCS Index for N - rate */
	{ "wl_nmode_protection", "auto", 0 },	/* 802.11n RTS/CTS protection (off|auto) */
	{ "wl_nreqd", "0", 0},			/* Require 802.11n support */
#endif	/* NPHY */
	{ "wl_leddc", "0x640000", 0},		/* 100% duty cycle for LED on router */
	{ "wl_vlan_prio_mode", "off", 0},	/* VLAN Priority support */
	/* WPA parameters */
	{ "wl_auth_mode", "none", 0 },		/* Network authentication mode (radius|none) */
	{ "wl_wpa_psk", "", 0 },		/* WPA pre-shared key */
	{ "wl_wpa_gtk_rekey", "0", 0 },		/* GTK rotation interval */
#ifdef CR
	{ "wl_crypto", "tkip+aes", 0 },		/* WPA data encryption */
#else
	{ "wl_crypto", "tkip", 0 },		/* WPA data encryption */
#endif	
	/* USR new parameters */
#ifdef CLIENT
	{ "cbAuthEncrypt", "open", 0 },		/* USR-authentication (none|wpa12|wpa2|wpa|radius-wpa12|radius-wpa2|radius-wpa|open|shared) */
#else
	{ "cbAuthEncrypt", "none", 0 },		/* USR-authentication (none|wpa12|wpa2|wpa|radius-wpa12|radius-wpa2|radius-wpa|open|shared) */
#endif	/* CLIENT */
#ifdef CR
	{ "cbEncryption", "tkip+aes", 0 },		/* USR-encryption (tkip|aes|tkip+aes|wl_wep_open|wl_wep_shared) */
#else	
	{ "cbEncryption", "none", 0 },		/* USR-encryption (tkip|aes|tkip+aes|wl_wep_open|wl_wep_shared) */	
#endif	/* CR */	
	{ "connection", "keepalive", 0 },		/* USR-pppoe connection (timeout|demand|keepalive) */ 
	//{ "wl_power", "79", 0 },		/* USR-TXPWR level - old power*/
	{ "wl_power", "76", 0 },		/* USR-TXPWR level qtxpower*/
	{ "wl_net_reauth", "3600", 0 },		/* Network Re-auth/PMK caching duration */
	{ "wl_akm", "", 0 },			/* WPA akm list */
#ifdef CR	
	/* WSC parameters */
	{ "wl_wsc_mode", "enabled", 0 },	/* enable/disable wsc */
	{ "wsc_mode", "enabled", 0 },		/* enable/disable wsc */
	{ "wsc_config_state", "0", 0 },		/* config state unconfiged */
	{ "wsc_device_pin", "12345670", 0 },		
	{ "wsc_mfstring", "U.S. Robotics Corporation", 0 },		
	{ "wl_wsc_reg", "disabled", 0 },		/* enable/disable built-in Registrar */
	{ "wsc_sta_pin", "0", 0 },		
	{ "wsc_timeout_enable", "0", 0 },		
	{ "wsc_addER", "0", 0 },		
	{ "wsc_uuid", "0x000102030405060708090A0B0C0D0EBB", 0 },		
#endif	/* CR */
	/* WME parameters (cwmin cwmax aifsn txop_b txop_ag adm_control oldest_first) */
	/* EDCA parameters for STA */
	{ "wl_wme_sta_be", "15 1023 3 0 0 off off", 0 },	/* WME STA AC_BE parameters */
	{ "wl_wme_sta_bk", "15 1023 7 0 0 off off", 0 },	/* WME STA AC_BK parameters */
	{ "wl_wme_sta_vi", "7 15 2 6016 3008 off off", 0 },	/* WME STA AC_VI parameters */
	{ "wl_wme_sta_vo", "3 7 2 3264 1504 off off", 0 },	/* WME STA AC_VO parameters */

	/* EDCA parameters for AP */
	{ "wl_wme_ap_be", "15 63 3 0 0 off off", 0 },		/* WME AP AC_BE parameters */
	{ "wl_wme_ap_bk", "15 1023 7 0 0 off off", 0 },		/* WME AP AC_BK parameters */
	{ "wl_wme_ap_vi", "7 15 1 6016 3008 off off", 0 },	/* WME AP AC_VI parameters */
	{ "wl_wme_ap_vo", "3 7 1 3264 1504 off off", 0 },	/* WME AP AC_VO parameters */

	{ "wl_wme_no_ack", "off", 0},		/* WME No-Acknowledgment mode */
	{ "wl_wme_apsd", "on", 0},		/* WME APSD mode */

	{ "wl_maxassoc", "128", 0},		/* Max associations driver could support */

	{ "wl_unit", "0", 0 },			/* Last configured interface */
	
	/* Restore defaults */
	{ "restore_defaults", "0", 0 },		/* Set to 0 to not restore defaults on boot */

	{ 0, 0, 0 }
};
